==> apache-tapestry-5.3.8-sources.zip: tapestry-jmx/src/test/java/org/example/testapp/services/AppModule.java <==
// Copyright 2010, 2011 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.example.testapp.services;

import org.apache.tapestry5.SymbolConstants;
import org.apache.tapestry5.ioc.MappedConfiguration;
import org.apache.tapestry5.ioc.ServiceBinder;
import org.apache.tapestry5.ioc.annotations.Decorate;
import org.apache.tapestry5.ioc.annotations.SubModule;
import org.apache.tapestry5.jmx.JmxModule;
import org.apache.tapestry5.jmx.MBeanSupport;

@SubModule(JmxModule.class)
public class AppModule
{
    public static void bind(ServiceBinder binder)
    {
        binder.bind(Sample.class);
    }

    public static void contributeApplicationDefaults(MappedConfiguration<String, String> configuration)
    {
        configuration.add(SymbolConstants.PRODUCTION_MODE, "false");
    }

    @Decorate(serviceInterface = Sample.class)
    public static Sample enableJMXForSample(Sample service, MBeanSupport managedBeanSupport)
    {
        managedBeanSupport.register(service, "org.example.testapp.services:service=Sample");

        return service;
    }
}

==> apache-tapestry-5.6.4-sources.zip: tapestry-jmx/src/test/java/org/example/testapp/services/AppModule.java <==
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.example.testapp.services;

import org.apache.tapestry5.SymbolConstants;
import org.apache.tapestry5.ioc.MappedConfiguration;
import org.apache.tapestry5.ioc.ServiceBinder;
import org.apache.tapestry5.ioc.annotations.Decorate;
import org.apache.tapestry5.ioc.annotations.ImportModule;
import org.apache.tapestry5.jmx.MBeanSupport;
import org.apache.tapestry5.jmx.modules.JmxModule;

@ImportModule(JmxModule.class)
public class AppModule
{
    public static void bind(ServiceBinder binder)
    {
        binder.bind(Sample.class);
    }

    public static void contributeApplicationDefaults(MappedConfiguration<String, String> configuration)
    {
        configuration.add(SymbolConstants.PRODUCTION_MODE, "false");
    }

    @Decorate(serviceInterface = Sample.class)
    public static Sample enableJMXForSample(Sample service, MBeanSupport managedBeanSupport)
    {
        managedBeanSupport.register(service, "org.example.testapp.services:service=Sample");

        return service;
    }
}
